// game.js for Perlenspiel 3.1

/*
Perlenspiel is a scheme by Professor Moriarty (bmoriarty@wpi.edu).
Perlenspiel is Copyright © 2009-14 Worcester Polytechnic Institute.
This file is part of Perlenspiel.

Perlenspiel is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published
by the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Perlenspiel is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You may have received a copy of the GNU Lesser General Public License
along with Perlenspiel. If not, see <http://www.gnu.org/licenses/>.
*/

// The following comment lines are for JSLint. Don't remove them!

/*jslint nomen: true, white: true */
/*global PS */

// This is a template for creating new Perlenspiel games

// All of the functions below MUST exist, or the engine will complain!

// Please fill out these comments with the appropriate information.
//     Project Title:	Mosaic Blox Toy
//            Author:	Alexis Barta
//     Creation Date:	June 6 2014
//      Last Updated:   June 7 2014

/* Build Notes:
	Build 1.0.2 : Clicking colors and shapes now have sound. Debugging window is gone.
	Build 1.0.1 : Beads now highlight with a dashing black or magenta border when hovered over
    Build 1.0.0 : Base code finished and base functionality works as intended
    
*/

// Put your global variables after this line
var gridX = 15;
var gridY = 20;

var bloxColor;
var defaultColor = PS.COLOR_BLACK;

// Put your function definitions after this line
function toyLayout(){
// This creates the toy board

	PS.color(PS.ALL, PS.ALL, PS.COLOR_WHITE);
	PS.color(0, PS.ALL, PS.COLOR_GRAY);
	PS.color(PS.ALL, 0, PS.COLOR_GRAY);
	PS.color(PS.ALL,12, PS.COLOR_GRAY);
	PS.color(14, PS.ALL, PS.COLOR_GRAY);
	PS.color(PS.ALL, 19, PS.COLOR_GRAY);
	PS.applyRect(1,13,18,6,PS.color,PS.COLOR_GRAY);
	PS.bgColor(PS.ALL,PS.ALL, PS.COLOR_GRAY);
	PS.bgAlpha(PS.ALL,PS.ALL, 225);

	PS.data(0, PS.ALL, "wall");
	PS.data(PS.ALL, 0, "wall");
	PS.data(PS.ALL,12, "wall");
	PS.data(14, PS.ALL, "wall");
	PS.data(PS.ALL,19, "wall");



	PS.border(PS.ALL, PS.ALL,0);

	PS.glyph(1, 13, "X");
	PS.color(1,13,PS.COLOR_WHITE)
	PS.glyphColor(1, 13, PS.COLOR_RED);
	PS.data(1,13,"reset");
};

function bloxColors(){
	//Red
	PS.color(3,17,PS.COLOR_RED);
	PS.radius(3,17, 50);
	PS.data(3,17,"red");

	//Orange
	PS.color(4,17,PS.COLOR_ORANGE);
	PS.radius(4,17, 50);
	PS.data(4,17,"orange");

	//Yellow
	PS.color(5,17,PS.COLOR_YELLOW);
	PS.radius(5,17, 50);
	PS.data(5,17,"yellow");

	//Green
	PS.color(6,17,PS.COLOR_GREEN);
	PS.radius(6,17, 50);
	PS.data(6,17,"green");

	//Blue
	PS.color(7,17,PS.COLOR_BLUE);
	PS.radius(7,17, 50);
	PS.data(7,17,"blue");

	//Violet
	PS.color(9,17,PS.COLOR_VIOLET);
	PS.radius(9,17, 50);
	PS.data(9,17,"violet");

	//Indigo
	PS.color(8,17,PS.COLOR_INDIGO);
	PS.radius(8,17, 50);
	PS.data(8,17,"indigo");

	//Black
	PS.color(10,17,PS.COLOR_BLACK);
	PS.radius(10,17, 50);
	PS.data(10,17,"black");

	//White
	PS.color(11,17,PS.COLOR_WHITE);
	PS.radius(11,17, 50);
	PS.data(11,17,"white");
	
};

function blox1x1(x,y){
	PS.color(x, y, defaultColor);
	PS.data(x, y, "1x1");
};

function blox1x2(x,y){
	PS.applyRect(x,y, 2, 1, PS.color, defaultColor);
	PS.applyRect(x,y, 2, 1, PS.data, "1x2");
};

function blox2x1(x,y){
	PS.applyRect(x,y, 1,2, PS.color, defaultColor);
	PS.applyRect(x,y, 1,2, PS.data, "2x1");
};

function bloxSquare(x,y){
	PS.applyRect(x,y, 2, 2, PS.color, defaultColor);
	PS.applyRect(x,y, 2, 2, PS.data, "Square");

};

function updateTimer(){
	blox1x1(3,15);
	blox1x2(5,15);
	blox2x1(8, 14);
	bloxSquare(10, 14);
}


// PS.init( system, options )
// Initializes the game
// This function should normally begin with a call to PS.gridSize( x, y )
// where x and y are the desired initial dimensions of the grid
// [system] = an object containing engine and platform information; see documentation for details
// [options] = an object with optional parameters; see documentation for details

PS.init = function( system, options ) {
	"use strict";

	// Use PS.gridSize( x, y ) to set the grid to
	// the initial dimensions you want (32 x 32 maximum)
	// Do this FIRST to avoid problems!
	// Otherwise you will get the default 8x8 grid
	var updateTimerID;
	updateTimerID = PS.timerStart(1, updateTimer);
	PS.gridSize(gridX, gridY); // replace with your own x/y values

	toyLayout();
	bloxColors();
	
	// Add any other initialization code you need here
	blox1x1(3,15);
	blox1x2(5,15);
	blox2x1(8, 14);
	bloxSquare(10, 14);

	PS.statusText("Blox Mosaic. Pick a color and shape!")


	PS.audioLoad("fx_powerup8"); //Color pick sound
	PS.audioLoad("fx_wilhelm"); //Reset sound
	PS.audioLoad("fx_jump7"); //Shape click sound


};

// PS.touch ( x, y, data, options )
// Called when the mouse button is clicked on a bead, or when a bead is touched
// It doesn't have to do anything
// [x] = zero-based x-position of the bead on the grid
// [y] = zero-based y-position of the bead on the grid
// [data] = the data value associated with this bead, 0 if none has been set
// [options] = an object with optional parameters; see documentation for details

PS.touch = function( x, y, data, options ) {
	"use strict";

	// Uncomment the following line to inspect parameters
	// PS.debug( "PS.touch() @ " + x + ", " + y + "\n" );

	// Add code here for mouse clicks/touches over a bead

	/* This set of coding deals with the buttons throughout the HUD. 
   It is clunkly, it is probably over coded. But it works. */

	// This resets the game
	if(PS.data(x,y) == "reset")
	{
		PS.audioPlay("fx_wilhelm");
		PS.init();
		
	}

	// This section makes the colors clickable
	if(PS.data(x,y) == "red")
	{
		bloxColor = PS.COLOR_RED;
		defaultColor = PS.COLOR_RED;
		PS.audioPlay("fx_powerup8");
	}

	if(PS.data(x,y) == "orange")
	{
		bloxColor = PS.COLOR_ORANGE;
		defaultColor = PS.COLOR_ORANGE;
		PS.audioPlay("fx_powerup8");
	}

	if(PS.data(x,y) == "yellow")
	{
		bloxColor = PS.COLOR_YELLOW;
		defaultColor = PS.COLOR_YELLOW;
		PS.audioPlay("fx_powerup8");
	}
	if(PS.data(x,y) == "green")
	{
		bloxColor = PS.COLOR_GREEN;
		defaultColor = PS.COLOR_GREEN;
		PS.audioPlay("fx_powerup8");
	}
	if(PS.data(x,y) == "blue")
	{
		bloxColor = PS.COLOR_BLUE;
		defaultColor = PS.COLOR_BLUE;
		PS.audioPlay("fx_powerup8");
	}
	if(PS.data(x,y) == "indigo")
	{
		bloxColor = PS.COLOR_INDIGO;
		defaultColor = PS.COLOR_INDIGO;
		PS.audioPlay("fx_powerup8");
	}
	if(PS.data(x,y) == "violet")
	{
		bloxColor = PS.COLOR_VIOLET;
		defaultColor = PS.COLOR_VIOLET;
		PS.audioPlay("fx_powerup8");
	}
	if(PS.data(x,y) == "black")
	{
		bloxColor = PS.COLOR_BLACK;
		defaultColor = PS.COLOR_BLACK;
		PS.audioPlay("fx_powerup8");
	}
	if(PS.data(x,y) == "white")
	{
		bloxColor = PS.COLOR_WHITE;
		defaultColor = PS.COLOR_WHITE;
		PS.audioPlay("fx_powerup8");
	}

	// This section spawns bloxs based on the shape pressed
	if(PS.data(x,y) == "1x1")
	{
		PS.color(PS.random(gridX-2),PS.random(gridY-9), bloxColor);
		PS.audioPlay("fx_jump1");
	}
	
	if(PS.data(x,y) == "1x2")
	{
		PS.applyRect(PS.random(gridX-3),PS.random(gridY-9), 2, 1, PS.color, bloxColor);
		PS.audioPlay("fx_jump7");
	}
	
	if(PS.data(x,y) == "2x1")
	{
		PS.applyRect(PS.random(gridX-2),PS.random(gridY-10), 1, 2, PS.color, bloxColor);
		PS.audioPlay("fx_jump2");
	}

	if(PS.data(x,y) == "Square")
	{
		PS.applyRect(PS.random(gridX-3),PS.random(gridY-10), 2, 2, PS.color, bloxColor);
		PS.audioPlay("fx_jump3");
	}
};

// PS.release ( x, y, data, options )
// Called when the mouse button is released over a bead, or when a touch is lifted off a bead
// It doesn't have to do anything
// [x] = zero-based x-position of the bead on the grid
// [y] = zero-based y-position of the bead on the grid
// [data] = the data value associated with this bead, 0 if none has been set
// [options] = an object with optional parameters; see documentation for details

PS.release = function( x, y, data, options ) {
	"use strict";

	// Uncomment the following line to inspect parameters
	// PS.debug( "PS.release() @ " + x + ", " + y + "\n" );

	// Add code here for when the mouse button/touch is released over a bead

	
};

// PS.enter ( x, y, button, data, options )
// Called when the mouse/touch enters a bead
// It doesn't have to do anything
// [x] = zero-based x-position of the bead on the grid
// [y] = zero-based y-position of the bead on the grid
// [data] = the data value associated with this bead, 0 if none has been set
// [options] = an object with optional parameters; see documentation for details

PS.enter = function( x, y, data, options ) {
	"use strict";

	// Uncomment the following line to inspect parameters
	// PS.debug( "PS.enter() @ " + x + ", " + y + "\n" );

	// Add code here for when the mouse cursor/touch enters a bead

	if(PS.data(x,y) != "wall")
	{
		PS.border(x,y,2);
		PS.borderColor(x,y,PS.COLOR_BLACK);	
	}

	if(PS.data(x,y) == "black")
	{
		PS.border(x,y,2);
		PS.borderColor(x,y,PS.COLOR_MAGENTA);	
	}

	if(PS.data(x,y) == "1x1")
	{
		PS.border(x,y,2);
		PS.borderColor(x,y,PS.COLOR_MAGENTA);	
	}
	
	if(PS.data(x,y) == "1x2")
	{
		PS.applyRect(5,15, 2, 1, PS.border, 2);
		PS.applyRect(5,15, 2, 1, PS.borderColor, PS.COLOR_MAGENTA);

	}
	
	if(PS.data(x,y) == "2x1")
	{
		PS.applyRect(8,14, 1, 2, PS.border, 2);
		PS.applyRect(8,14, 1, 2, PS.borderColor, PS.COLOR_MAGENTA);
	}

	if(PS.data(x,y) == "Square")
	{
		PS.applyRect(10,14, 2, 2, PS.border, 2);
		PS.applyRect(10,14, 2, 2, PS.borderColor, PS.COLOR_MAGENTA)
	}
};

// PS.exit ( x, y, data, options )
// Called when the mouse cursor/touch exits a bead
// It doesn't have to do anything
// [x] = zero-based x-position of the bead on the grid
// [y] = zero-based y-position of the bead on the grid
// [data] = the data value associated with this bead, 0 if none has been set
// [options] = an object with optional parameters; see documentation for details

PS.exit = function( x, y, data, options ) {
	"use strict";

	// Uncomment the following line to inspect parameters
	// PS.debug( "PS.exit() @ " + x + ", " + y + "\n" );

	// Add code here for when the mouse cursor/touch exits a bead

	

	if(PS.data(x,y) == "1x2")
	{
		PS.applyRect(5,15, 2, 1, PS.border, 0);
		
	}
	
	if(PS.data(x,y) == "2x1")
	{
		PS.applyRect(8,14, 1, 2, PS.border, 0);
		
	}

	if(PS.data(x,y) == "Square")
	{
		PS.applyRect(10,14, 2, 2, PS.border, 0);
		
	}

	PS.border(x,y,0);
};

// PS.exitGrid ( options )
// Called when the mouse cursor/touch exits the grid perimeter
// It doesn't have to do anything
// [options] = an object with optional parameters; see documentation for details

PS.exitGrid = function( options ) {
	"use strict";

	// Uncomment the following line to verify operation
	// PS.debug( "PS.exitGrid() called\n" );

	// Add code here for when the mouse cursor/touch moves off the grid
};

// PS.keyDown ( key, shift, ctrl, options )
// Called when a key on the keyboard is pressed
// It doesn't have to do anything
// [key] = ASCII code of the pressed key, or one of the following constants:
// Arrow keys = PS.ARROW_UP, PS.ARROW_DOWN, PS.ARROW_LEFT, PS.ARROW_RIGHT
// Function keys = PS.F1 through PS.F1
// [shift] = true if shift key is held down, else false
// [ctrl] = true if control key is held down, else false
// [options] = an object with optional parameters; see documentation for details

PS.keyDown = function( key, shift, ctrl, options ) {
	"use strict";

	// Uncomment the following line to inspect parameters
	//	PS.debug( "DOWN: key = " + key + ", shift = " + shift + "\n" );

	// Add code here for when a key is pressed
};

// PS.keyUp ( key, shift, ctrl, options )
// Called when a key on the keyboard is released
// It doesn't have to do anything
// [key] = ASCII code of the pressed key, or one of the following constants:
// Arrow keys = PS.ARROW_UP, PS.ARROW_DOWN, PS.ARROW_LEFT, PS.ARROW_RIGHT
// Function keys = PS.F1 through PS.F12
// [shift] = true if shift key is held down, false otherwise
// [ctrl] = true if control key is held down, false otherwise
// [options] = an object with optional parameters; see documentation for details

PS.keyUp = function( key, shift, ctrl, options ) {
	"use strict";

	// Uncomment the following line to inspect parameters
	// PS.debug( "PS.keyUp(): key = " + key + ", shift = " + shift + ", ctrl = " + ctrl + "\n" );

	// Add code here for when a key is released
};

// PS.input ( sensors, options )
// Called when an input device event (other than mouse/touch/keyboard) is detected
// It doesn't have to do anything
// [sensors] = an object with sensor information; see documentation for details
// [options] = an object with optional parameters; see documentation for details

PS.input = function( sensors, options ) {
	"use strict";

	// Uncomment the following block to inspect parameters
	/*
	PS.debug( "PS.input() called\n" );
	var device = sensors.wheel; // check for scroll wheel
	if ( device )
	{
		PS.debug( "sensors.wheel = " + device + "\n" );
	}
	*/
	
	// Add code here for when an input event is detected
};

